# ##################################################################################################
#  Copyright (c) 2020. HuiiBuh                                                                     #
#  This file (__init__.py) is part of AsyncSpotify which is released under MIT.                    #
#  You are not allowed to use this code or this file for another project without                   #
#  linking to the original source.                                                                 #
# ##################################################################################################

"""
All modules related to authentication
"""

from .spotify_cookies import SpotifyCookie
from .spotify_authorization_token import SpotifyAuthorisationToken
